@@ -6,6 +6,7 @@ import qualified Data.List as L
 import qualified Data.Map.Strict as M
 import qualified Data.Maybe as DM
 import qualified Data.Set as S
+import qualified Text.PrettyPrint.HughesPJClass as P
 import qualified System.Directory as D
 import qualified System.Environment as E
 import qualified System.FilePath as F
@@ -74,13 +75,12 @@ featureName version mbProfile =
 
 printTokens :: API -> Registry -> IO ()
 printTokens api registry = do
-  let comment =
-        ["All enumeration tokens from the",
-         "<http://www.opengl.org/registry/ OpenGL registry>."]
-  startModule ["Tokens"] (Just "{-# LANGUAGE CPP, PatternSynonyms, ScopedTypeVariables #-}\n#if __GLASGOW_HASKELL__ >= 800\n{-# OPTIONS_GHC -Wno-missing-pattern-synonym-signatures #-}\n#endif") comment $ \moduleName h -> do
-    SI.hPutStrLn h $ "module " ++ moduleName ++ " where"
-    SI.hPutStrLn h ""
-    SI.hPutStrLn h $ "import " ++ moduleNameFor ["Types"]
+  let cmnt =
+        [Comment "All enumeration tokens from the",
+         Comment "<http://www.opengl.org/registry/ OpenGL registry>."]
+  startModule ["Tokens"] (Just "{-# LANGUAGE CPP, PatternSynonyms, ScopedTypeVariables #-}\n#if __GLASGOW_HASKELL__ >= 800\n{-# OPTIONS_GHC -Wno-missing-pattern-synonym-signatures #-}\n#endif") cmnt $ \moduleName h -> do
+    hRender h $ Module moduleName P.empty
+    hRender h $ Import (moduleNameFor ["Types"]) P.empty
     SI.hPutStrLn h ""
     mapM_ (SI.hPutStrLn h . unlines . convertEnum)
       [ e
@@ -90,40 +90,37 @@ printTokens api registry = do
 
 printGroups :: API -> Registry -> IO ()
 printGroups api registry = do
-  let comment =
-        ["All enumeration groups from the",
-         "<http://www.opengl.org/registry/ OpenGL registry>."]
-  startModule ["Groups"] Nothing comment $ \moduleName h -> do
-    SI.hPutStrLn h $ "module " ++ moduleName ++ " ("
-    SI.hPutStrLn h $ "  -- $EnumerantGroups"
-    SI.hPutStrLn h $ ") where"
-    SI.hPutStrLn h ""
-    SI.hPutStrLn h $ "-- $EnumerantGroups"
-    SI.hPutStrLn h $ "-- Note that the actual set of valid values depend on the OpenGL version, the"
-    SI.hPutStrLn h $ "-- chosen profile and the supported extensions. Therefore, the groups mentioned"
-    SI.hPutStrLn h $ "-- here should only be considered a rough guideline, for details see the OpenGL"
-    SI.hPutStrLn h $ "-- specification."
+  let cmnt =
+        [Comment "All enumeration groups from the",
+         Comment "<http://www.opengl.org/registry/ OpenGL registry>."]
+  startModule ["Groups"] Nothing cmnt $ \moduleName h -> do
+    hRender h $ Module moduleName (P.text "(\n  -- $EnumerantGroups\n)")
+    hRender h $ Comment "$EnumerantGroups"
+    hRender h $ Comment "Note that the actual set of valid values depend on the OpenGL version, the"
+    hRender h $ Comment "chosen profile and the supported extensions. Therefore, the groups mentioned"
+    hRender h $ Comment "here should only be considered a rough guideline, for details see the OpenGL"
+    hRender h $ Comment "specification."
     CM.forM_ (M.assocs (groups registry)) $ \(gn, g) -> do
       let ugn = unGroupName gn
           es = getGroupEnums api registry g
-      SI.hPutStrLn h $ "--"
-      SI.hPutStrLn h $ "-- === #" ++ ugn ++ "# " ++ ugn
-      SI.hPutStrLn h $ "-- " ++ groupHeader es
-      SI.hPutStrLn h $ "--"
+      hRender h $ Comment ""
+      hRender h $ Comment ("=== #" ++ ugn ++ "# " ++ ugn)
+      hRender h $ Comment (groupHeader es)
+      hRender h $ Comment ""
       -- TODO: Improve the alias computation below. It takes quadratic time and
       -- is very naive about what is the canonical name and what is an alias.
       CM.forM_ es $ \e -> do
         let same = L.sort [ f | f <- es, enumValue e == enumValue f ]
         CM.when (e == head same) $ do
-          SI.hPutStrLn h $ "-- * " ++ linkToToken e ++
+          hRender h $ Comment ("* " ++ linkToToken e ++
             (case tail same of
                 [] -> ""
                 aliases -> " (" ++ al ++ ": " ++ L.intercalate ", " (map linkToToken aliases) ++ ")"
                   where al | length aliases == 1 = "alias"
-                           | otherwise = "aliases")
+                           | otherwise = "aliases"))
 
 linkToToken :: Enum' -> String
-linkToToken e = "'" ++ moduleNameFor ["Tokens"] ++ "." ++ (unEnumName . enumName) e ++ "'"
+linkToToken e = "'" ++ (case moduleNameFor ["Tokens"] of ModuleName mn -> mn) ++ "." ++ (unEnumName . enumName) e ++ "'"
 
 -- There are several enums which are mentioned in groups, but commented out in
 -- enums (12 GL_*_ICC_SGIX enumerants). These are implicitly filtered out below.
@@ -154,17 +151,16 @@ signatureMap registry = fst $ M.foldl' step (M.empty, 0::Integer) (commands regi
 
 printForeign :: M.Map String String -> IO ()
 printForeign sigMap = do
-  let comment = ["All foreign imports."]
-  startModule ["Foreign"] (Just "{-# LANGUAGE CPP #-}\n{-# OPTIONS_HADDOCK hide #-}") comment $ \moduleName h -> do
-    SI.hPutStrLn h $ "module " ++ moduleName ++ " where"
-    SI.hPutStrLn h ""
-    SI.hPutStrLn h "import Foreign.C.Types"
-    SI.hPutStrLn h "import Foreign.Marshal.Error ( throwIf )"
-    SI.hPutStrLn h "import Foreign.Ptr"
-    SI.hPutStrLn h $ "import " ++ moduleNameFor ["GetProcAddress"] ++ " ( getProcAddress )"
-    SI.hPutStrLn h $ "import " ++ moduleNameFor ["Types"]
-    SI.hPutStrLn h "import Numeric.Fixed"
-    SI.hPutStrLn h "import Numeric.Half"
+  let cmnt = [Comment "All foreign imports."]
+  startModule ["Foreign"] (Just "{-# LANGUAGE CPP #-}\n{-# OPTIONS_HADDOCK hide #-}") cmnt $ \moduleName h -> do
+    hRender h $ Module moduleName P.empty
+    hRender h $ Import (ModuleName "Foreign.C.Types") P.empty
+    hRender h $ Import (ModuleName "Foreign.Marshal.Error") (P.text "( throwIf )")
+    hRender h $ Import (ModuleName "Foreign.Ptr") P.empty
+    hRender h $ Import (moduleNameFor ["GetProcAddress"]) (P.text "( getProcAddress )")
+    hRender h $ Import (moduleNameFor ["Types"]) P.empty
+    hRender h $ Import (ModuleName "Numeric.Fixed") P.empty
+    hRender h $ Import (ModuleName "Numeric.Half") P.empty
     SI.hPutStrLn h ""
     SI.hPutStrLn h "getCommand :: String -> IO (FunPtr a)"
     SI.hPutStrLn h "getCommand cmd ="
@@ -182,36 +178,31 @@ justifyRight n c xs = reverse . take (max n (length xs)) . (++ repeat c) . rever
 
 printFunctions :: API -> Registry -> M.Map String String -> IO ()
 printFunctions api registry sigMap = do
-  let comment =
-        ["All raw functions from the",
-         "<http://www.opengl.org/registry/ OpenGL registry>."]
+  let cmnt =
+        [Comment "All raw functions from the",
+         Comment "<http://www.opengl.org/registry/ OpenGL registry>."]
       cmds = chunksOf 100 . M.toAscList . commands $ registry
       mnames = [ [ "Functions", "F" ++ justifyRight 2 '0' (show i) ] |
                    i <- [ 1 .. length cmds ] ]
-  startModule ["Functions"] Nothing comment $ \moduleName h -> do
-    SI.hPutStrLn h $ "module " ++ moduleName ++ " ("
-    SI.hPutStrLn h . separate (("module " ++) . moduleNameFor) $ mnames
-    SI.hPutStrLn h ") where"
-    SI.hPutStrLn h ""
-    mapM_ (SI.hPutStrLn h . ("import " ++) . moduleNameFor) mnames
+  startModule ["Functions"] Nothing cmnt $ \moduleName h -> do
+    hRender h $ Module moduleName (P.text ("(\n" ++ separate (\x -> "module " ++ (case moduleNameFor x of ModuleName mn -> mn)) mnames ++ "\n)"))
+    CM.forM_ mnames $ \mname ->
+      hRender h $ Import (moduleNameFor mname) P.empty
   CM.zipWithM_ (printSubFunctions api registry sigMap) mnames cmds
 
 printSubFunctions :: API -> Registry -> M.Map String String ->
                      [String] -> [(CommandName, Command)] -> IO ()
 printSubFunctions api registry sigMap mname cmds = do
-  let comment =
-        ["Raw functions from the",
-         "<http://www.opengl.org/registry/ OpenGL registry>."]
-  startModule mname (Just "{-# OPTIONS_HADDOCK hide #-}") comment $ \moduleName h -> do
-    SI.hPutStrLn h $ "module " ++ moduleName ++ " ("
-    SI.hPutStrLn h . separate unCommandName . map fst $ cmds
-    SI.hPutStrLn h ") where"
-    SI.hPutStrLn h ""
-    SI.hPutStrLn h "import Control.Monad.IO.Class ( MonadIO(..) )"
-    SI.hPutStrLn h "import Foreign.Ptr"
-    SI.hPutStrLn h $ "import " ++ moduleNameFor ["Foreign"]
-    SI.hPutStrLn h $ "import " ++ moduleNameFor ["Types"]
-    SI.hPutStrLn h "import System.IO.Unsafe ( unsafePerformIO )"
+  let cmnt =
+        [Comment "Raw functions from the",
+         Comment "<http://www.opengl.org/registry/ OpenGL registry>."]
+  startModule mname (Just "{-# OPTIONS_HADDOCK hide #-}") cmnt $ \moduleName h -> do
+    hRender h $ Module moduleName (P.text ("(\n" ++ separate unCommandName (map fst cmds) ++ "\n)"))
+    hRender h $ Import (ModuleName "Control.Monad.IO.Class") (P.text "( MonadIO(..) )")
+    hRender h $ Import (ModuleName "Foreign.Ptr") P.empty
+    hRender h $ Import (moduleNameFor ["Foreign"]) P.empty
+    hRender h $ Import (moduleNameFor ["Types"]) P.empty
+    hRender h $ Import (ModuleName "System.IO.Unsafe") (P.text "( unsafePerformIO )")
     SI.hPutStrLn h ""
     mapM_ (SI.hPutStrLn h . showCommand api registry sigMap . snd) cmds
 
@@ -339,24 +330,20 @@ printReExports extModules = do
       reExports = [ (cat, L.sort mangledExtNames)
                   | (cat, mangledExtNames) <- M.toList extMap ]
   CM.forM_ reExports $ \((category, mangledCategory), mangledExtNames) -> do
-    let comment = ["A convenience module, combining all raw modules containing " ++ category ++ " extensions."]
-    startModule [mangledCategory] Nothing comment $ \moduleName h -> do
-      SI.hPutStrLn h $ "module "++ moduleName ++ " ("
-      SI.hPutStrLn h $ separate (\mangledExtName -> "module " ++ extensionNameFor mangledExtName) mangledExtNames
-      SI.hPutStrLn h ") where"
-      SI.hPutStrLn h ""
+    let cmnt = [Comment ("A convenience module, combining all raw modules containing " ++ category ++ " extensions.")]
+    startModule [mangledCategory] Nothing cmnt $ \moduleName h -> do
+      hRender h $ Module moduleName (P.text ("(\n" ++ separate (\mangledExtName -> "module " ++ (case extensionNameFor mangledExtName of ModuleName mn -> mn)) mangledExtNames ++ "\n)"))
       CM.forM_ mangledExtNames $ \mangledExtName ->
-        SI.hPutStrLn h $ "import " ++ extensionNameFor mangledExtName
+        hRender h $ Import (extensionNameFor mangledExtName) P.empty
 
 printExtensionSupport :: [ExtensionModule] -> IO ()
 printExtensionSupport extModules = do
-  let comment = ["Extension support predicates."]
-  startModule ["ExtensionPredicates"] (Just "{-# OPTIONS_HADDOCK hide #-}") comment $ \moduleName h -> do
-    SI.hPutStrLn h $ "module "++ moduleName ++ " where"
-    SI.hPutStrLn h $ ""
-    SI.hPutStrLn h $ "import Control.Monad.IO.Class ( MonadIO(..) )"
-    SI.hPutStrLn h $ "import Data.Set ( member )"
-    SI.hPutStrLn h $ "import " ++ moduleNameFor ["GetProcAddress"] ++ " ( getExtensions, extensions )"
+  let cmnt = [Comment "Extension support predicates."]
+  startModule ["ExtensionPredicates"] (Just "{-# OPTIONS_HADDOCK hide #-}") cmnt $ \moduleName h -> do
+    hRender h $ Module moduleName P.empty
+    hRender h $ Import (ModuleName "Control.Monad.IO.Class") (P.text "( MonadIO(..) )")
+    hRender h $ Import (ModuleName "Data.Set") (P.text "( member )")
+    hRender h $ Import (moduleNameFor ["GetProcAddress"]) (P.text "( getExtensions, extensions )")
     let names = sortUnique [ extName | (extName, _, _) <- extModules]
     CM.forM_ names $ \extName -> do
       let predNameMonad = extensionPredicateNameMonad extName
@@ -365,18 +352,18 @@ printExtensionSupport extModules = do
                                 , extensionNameCategory extName
                                  , extensionNameName extName ]
       SI.hPutStrLn h $ ""
-      SI.hPutStrLn h $ "-- | Is the " ++ extensionHyperlink extName ++ " extension supported?"
+      hRender h $ Comment ("| Is the " ++ extensionHyperlink extName ++ " extension supported?")
       SI.hPutStrLn h $ predNameMonad ++ " :: MonadIO m => m Bool"
       SI.hPutStrLn h $ predNameMonad ++ " = getExtensions >>= (return . member " ++ show extString ++ ")"
       SI.hPutStrLn h $ ""
-      SI.hPutStrLn h $ "-- | Is the " ++ extensionHyperlink extName ++ " extension supported?"
-      SI.hPutStrLn h $ "-- Note that in the presence of multiple contexts with different capabilities,"
-      SI.hPutStrLn h $ "-- this might be wrong. Use '" ++ predNameMonad ++ "' in those cases instead."
+      hRender h $ Comment ("| Is the " ++ extensionHyperlink extName ++ " extension supported?")
+      hRender h $ Comment "Note that in the presence of multiple contexts with different capabilities,"
+      hRender h $ Comment ("this might be wrong. Use '" ++ predNameMonad ++ "' in those cases instead.")
       SI.hPutStrLn h $ predName ++ " :: Bool"
       SI.hPutStrLn h $ predName ++ " = member " ++ show extString ++ " extensions"
       SI.hPutStrLn h $ "{-# NOINLINE " ++ predName ++ " #-}"
 
-extensionNameFor :: ExtensionName -> String
+extensionNameFor :: ExtensionName -> ModuleName
 extensionNameFor mangledExtName = moduleNameFor [extensionNameCategory mangledExtName, extensionNameName mangledExtName]
 
 supports :: API -> Maybe [API] -> Bool
@@ -394,33 +381,32 @@ printExtension :: [String] -> Maybe ExtensionName -> ExtensionParts -> IO ()
 printExtension moduleNameSuffix mbExtName (ts, es, cs) = do
   let pragma = if null es then Nothing else Just "{-# LANGUAGE PatternSynonyms #-}"
   startModule moduleNameSuffix pragma [] $ \moduleName h -> do
-    SI.hPutStrLn h $ "module "++ moduleName ++ " ("
-    flip (maybe (return ())) mbExtName $ \extName -> do
-      SI.hPutStrLn h "  -- * Extension Support"
-      SI.hPutStrLn h $ separate id [ extensionPredicateNameMonad extName
-                                   , extensionPredicateName extName ] ++ ","
-    CM.unless (null ts) $ do
-      SI.hPutStrLn h "  -- * Types"
-      SI.hPutStr h $ separate unTypeName ts
-      SI.hPutStrLn h $ if null es && null cs then "" else ","
-    CM.unless (null es) $ do
-      SI.hPutStrLn h "  -- * Enums"
-      SI.hPutStr h $ separate (("pattern " ++) . unEnumName . enumName) es
-      SI.hPutStrLn h $ if null cs then "" else ","
-    CM.unless (null cs) $ do
-      SI.hPutStrLn h "  -- * Functions"
-      SI.hPutStr h $ separate (unCommandName . commandName) cs
-      SI.hPutStrLn h ""
-    SI.hPutStrLn h ") where"
-    SI.hPutStrLn h ""
+    let extStr = flip (maybe "") mbExtName $ \extName ->
+                   "  -- * Extension Support\n" ++
+                   separate id [ extensionPredicateNameMonad extName
+                               , extensionPredicateName extName ] ++ ",\n"
+        typeStr  | null ts = ""
+                 | otherwise = "  -- * Types\n" ++
+                               separate unTypeName ts ++
+                               if null es && null cs then "\n" else ",\n"
+        enumStr | null es = ""
+                | otherwise = "  -- * Enums\n" ++
+                              separate (("pattern " ++) . unEnumName . enumName) es ++
+                              if null cs then "\n" else ",\n"
+        funcStr | null cs = ""
+                | otherwise = "  -- * Functions\n" ++
+                              separate (unCommandName . commandName) cs ++
+                              "\n"
+
+    hRender h $ Module moduleName (P.text ("(\n" ++ extStr ++ typeStr ++ enumStr ++ funcStr ++ ")"))
     CM.when (DM.isJust mbExtName) $
-      SI.hPutStrLn h $ "import " ++ moduleNameFor ["ExtensionPredicates"]
+      hRender h $ Import (moduleNameFor ["ExtensionPredicates"]) P.empty
     CM.unless (null ts) $
-      SI.hPutStrLn h $ "import " ++ moduleNameFor ["Types"]
+      hRender h $ Import (moduleNameFor ["Types"]) P.empty
     CM.unless (null es) $
-      SI.hPutStrLn h $ "import " ++ moduleNameFor ["Tokens"]
+      hRender h $ Import (moduleNameFor ["Tokens"]) P.empty
     CM.unless (null cs) $
-      SI.hPutStrLn h $ "import " ++ moduleNameFor ["Functions"]
+      hRender h $ Import (moduleNameFor ["Functions"]) P.empty
 
 extensionPredicateName :: ExtensionName -> String
 extensionPredicateName extName =
@@ -443,19 +429,16 @@ printTopLevel api extModules = do
       profToReExport = profileToReExport api
       lastComp = featureName (latestVersion api) profToReExport
       moduleNames = [ moduleNameFor [c] | c <- [ lastComp, "GetProcAddress" ] ++ mangledCategories ]
-      comment = [ L.intercalate " "
-                    [ "A convenience module, combining the latest"
-                    , apiName api
-                    , maybe "version" (\p -> unProfileName p ++ " profile") profToReExport
-                    , "plus" ]
-                , "all extensions." ]
-  startModule [] Nothing comment $ \moduleName h -> do
-    SI.hPutStrLn h $ "module "++ moduleName ++ " ("
-    SI.hPutStrLn h $ separate (\m -> "module " ++ m) moduleNames
-    SI.hPutStrLn h ") where"
-    SI.hPutStrLn h ""
+      cmnt = [ Comment (L.intercalate " "
+                 [ "A convenience module, combining the latest"
+                 , apiName api
+                 , maybe "version" (\p -> unProfileName p ++ " profile") profToReExport
+                 , "plus" ])
+             , Comment "all extensions." ]
+  startModule [] Nothing cmnt $ \moduleName h -> do
+    hRender h $ Module moduleName (P.text ("(\n" ++ separate (\(ModuleName m) -> "module " ++ m) moduleNames ++ "\n)"))
     CM.forM_ moduleNames $ \theModuleName ->
-      SI.hPutStrLn h $ "import " ++ theModuleName
+      hRender h $ Import theModuleName P.empty
 
 apiName :: API -> String
 apiName api = case unAPI api of
@@ -467,7 +450,7 @@ apiName api = case unAPI api of
 sortUnique :: Ord a => [a] -> [a]
 sortUnique = S.toList . S.fromList
 
-startModule :: [String] -> Maybe String -> [String] -> (String -> SI.Handle -> IO ()) -> IO ()
+startModule :: [String] -> Maybe String -> [Comment] -> (ModuleName -> SI.Handle -> IO ()) -> IO ()
 startModule moduleNameSuffix mbPragma comments action = do
   let path = modulePathFor moduleNameSuffix
       moduleName = moduleNameFor moduleNameSuffix
@@ -476,8 +459,8 @@ startModule moduleNameSuffix mbPragma comments action = do
     printModuleHeader h mbPragma moduleName comments
     action moduleName h
 
-moduleNameFor :: [String] -> String
-moduleNameFor = L.intercalate "." . moduleNameParts
+moduleNameFor :: [String] -> ModuleName
+moduleNameFor = ModuleName . L.intercalate "." . moduleNameParts
 
 modulePathFor :: [String] -> FilePath
 modulePathFor moduleNameSuffix = F.joinPath (moduleNameParts moduleNameSuffix) `F.addExtension` "hs"
@@ -485,23 +468,23 @@ modulePathFor moduleNameSuffix = F.joinPath (moduleNameParts moduleNameSuffix) `
 moduleNameParts :: [String] -> [String]
 moduleNameParts = (["Graphics", "GL"] ++)
 
-printModuleHeader :: SI.Handle -> Maybe String -> String -> [String] -> IO ()
-printModuleHeader h mbPragma moduleName comments = do
+printModuleHeader :: SI.Handle -> Maybe String -> ModuleName -> [Comment] -> IO ()
+printModuleHeader h mbPragma (ModuleName moduleName) comments = do
   maybe (return ()) (SI.hPutStrLn h) mbPragma
-  SI.hPutStrLn h "--------------------------------------------------------------------------------"
-  SI.hPutStrLn h "-- |"
-  SI.hPutStrLn h $ "-- Module      :  " ++ moduleName
-  SI.hPutStrLn h "-- Copyright   :  (c) Sven Panne 2016"
-  SI.hPutStrLn h "-- License     :  BSD3"
-  SI.hPutStrLn h "--"
-  SI.hPutStrLn h "-- Maintainer  :  Sven Panne <svenpanne@gmail.com>"
-  SI.hPutStrLn h "-- Stability   :  stable"
-  SI.hPutStrLn h "-- Portability :  portable"
-  SI.hPutStrLn h "--"
+  hRender h $ Comment "------------------------------------------------------------------------------"
+  hRender h $ Comment "|"
+  hRender h $ Comment ("Module      :  " ++ moduleName)
+  hRender h $ Comment "Copyright   :  (c) Sven Panne 2016"
+  hRender h $ Comment "License     :  BSD3"
+  hRender h $ Comment ""
+  hRender h $ Comment "Maintainer  :  Sven Panne <svenpanne@gmail.com>"
+  hRender h $ Comment "Stability   :  stable"
+  hRender h $ Comment "Portability :  portable"
+  hRender h $ Comment ""
   CM.unless (null comments) $ do
-    mapM_ (SI.hPutStrLn h . ("-- " ++)) comments
-    SI.hPutStrLn h "--"
-  SI.hPutStrLn h "--------------------------------------------------------------------------------"
+    mapM_ (hRender h) comments
+    hRender h $ Comment ""
+  hRender h $ Comment "------------------------------------------------------------------------------"
   SI.hPutStrLn h ""
 
 -- Annoyingly enough, the OpenGL registry doesn't contain any enums for
@@ -573,9 +556,9 @@ convertEnum e =
 
 showCommand :: API -> Registry -> M.Map String String -> Command -> String
 showCommand api registry sigMap c =
-  showString (take 80 ("-- " ++ name ++ " " ++ repeat '-') ++ "\n\n") .
+  showString (P.render (P.pPrint (Comment (take 77 (name ++ " " ++ repeat '-'))) P.$+$ P.text "" P.$+$ P.text "")) .
 
-  showString comment .
+  showString (P.render cmnt) .
 
   showString (name ++ "\n") .
   showString ("  :: MonadIO m\n") .
@@ -596,9 +579,9 @@ showCommand api registry sigMap c =
         signature withComment = showSignatureFromCommand registry c withComment
         urls = M.findWithDefault [] (api, CommandName name) manPageURLs
         links = L.intercalate " or " (map renderURL urls)
-        comment = case concat (man ++ ve ++ al) of
-                    ""  -> ""
-                    cs -> "-- |" ++ cs ++ "\n"
+        cmnt = case concat (man ++ ve ++ al) of
+                 ""  -> P.empty
+                 cs -> P.pPrint (Comment ("|" ++ cs)) P.$+$ P.text ""
         man = case urls of
                 []  -> []
                 [_] -> [" Manual page for "  ++ links ++ "."]
@@ -621,20 +604,20 @@ showSignatureFromCommand registry c withComment =
      [showSignatureElement registry withComment True (resultType c)])
 
 showSignatureElement :: Registry -> Bool -> Bool -> SignatureElement -> String
-showSignatureElement registry withComment isResult sigElem = el ++ comment
+showSignatureElement registry withComment isResult sigElem = el ++ cmnt
   where el | isResult  = monad ++ " " ++ showsPrec 11 sigElem ""
            | otherwise = show sigElem
         monad | withComment = "m"
               | otherwise = "IO"
-        comment | withComment = showComment registry name sigElem
-                | otherwise   = ""
+        cmnt | withComment = P.render (showComment registry name sigElem P.$+$ P.text "")
+             | otherwise   = ""
         name | isResult  = ""
              | otherwise = signatureElementName sigElem
 
-showComment :: Registry -> String -> SignatureElement -> String
+showComment :: Registry -> String -> SignatureElement -> P.Doc
 showComment registry name sigElem
-  | null name' && null info = "\n"
-  | otherwise = " -- ^" ++ name' ++ info ++ ".\n"
+  | null name' && null info = P.text ""
+  | otherwise = P.text " " P.<> P.pPrint (Comment ("^" ++ name' ++ info ++ "."))
 
   where name' | null name = ""
               | otherwise = " " ++ inlineCode name
@@ -720,3 +703,34 @@ toEnumType eNamespace eGroup eType suffix eName = TypeName $
 
 isMask :: TypeName -> Bool
 isMask = (== TypeName "GLbitfield")
+
+--------------------------------------------------------------------------------
+
+data Module = Module ModuleName Exports
+
+instance P.Pretty Module where
+  pPrint (Module mn ex) = P.text "module" P.<+> P.pPrint mn P.<+> ex P.<+> P.text "where\n"
+
+type Exports = P.Doc
+
+data Import = Import ModuleName ImportSpecs
+
+instance P.Pretty Import where
+  pPrint (Import mn im) = P.text "import" P.<+> P.pPrint mn P.<+> im
+
+type ImportSpecs = P.Doc
+
+newtype ModuleName = ModuleName String
+
+instance P.Pretty ModuleName where
+  pPrint (ModuleName m) = P.text m
+
+newtype Comment = Comment String
+
+instance P.Pretty Comment where
+  pPrint (Comment c) | null c         = P.text "--"
+                     | all (== '-') c = P.pPrint (Comment "") P.<> P.text c
+                     | otherwise      = P.pPrint (Comment "") P.<+> P.text c
+
+hRender :: P.Pretty a => SI.Handle -> a -> IO ()
+hRender h = SI.hPutStrLn h . P.render . P.pPrint
